Testing
=======

* Testing tool: ``pytest``
* Command line: ``pytest [-v|-vv] [-s]``. Should be run from the base directory of the repository.
* Tests files location::

    awsmate
        |___tests
                |
                |___unit

* Tests status: |Test status|

.. |Test status| image:: https://github.com/shlublu/awsmate/actions/workflows/tests.yaml/badge.svg?branch=master
    :alt: Test status
